==> haskell-network-info-0.2.0.10-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-info.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 network-info
version:              0.2.0.10
visibility:           public
id:                   network-info-0.2.0.10-HRUWFIvhsIZ1Lv1pmqWRl0
key:                  network-info-0.2.0.10-HRUWFIvhsIZ1Lv1pmqWRl0
license:              BSD-3-Clause
maintainer:           Jacob Stanley <jacob@stanley.io>
author:               Jacob Stanley
homepage:             http://github.com/jystic/network-info
synopsis:             Access the local computer'\''s basic network configuration
description:
    This library provides simple read-only access to the
    local computer'\''s networking configuration. It is
    currently capable of getting a list of all the network
    interfaces and their respective IPv4, IPv6 and MAC
    addresses.

    network-info has been tested and is known to work on
    Ubuntu 10.10, FreeBSD 9.0, Mac OS X 10.6.4 and Windows
    XP/7. It probably works on other flavours of Linux,
    OS X, FreeBSD and Windows as well.

category:             Network
abi:                  2332ce7b122334f060051ca1c870d1ba
exposed:              True
exposed-modules:      Network.Info
import-dirs:          /usr/lib/ghc-9.0.1/site-local/network-info-0.2.0.10
library-dirs:         /usr/lib/ghc-9.0.1/site-local/network-info-0.2.0.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/network-info-0.2.0.10
hs-libraries:         HSnetwork-info-0.2.0.10-HRUWFIvhsIZ1Lv1pmqWRl0
depends:              base-4.15.0.0
haddock-interfaces:
    /usr/share/doc/haskell-network-info/html/network-info.haddock

haddock-html:         /usr/share/doc/haskell-network-info/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-info-0.2.1-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-info.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 network-info
version:              0.2.1
visibility:           public
id:                   network-info-0.2.1-9GScy3IMZku1XH8B3cDTYU
key:                  network-info-0.2.1-9GScy3IMZku1XH8B3cDTYU
license:              BSD-3-Clause
maintainer:           Jacob Stanley <jacob@stanley.io>
author:               Jacob Stanley
homepage:             http://github.com/jacobstanley/network-info
synopsis:             Access the local computer'\''s basic network configuration
description:
    This library provides simple read-only access to the
    local computer'\''s networking configuration. It is
    currently capable of getting a list of all the network
    interfaces and their respective IPv4, IPv6 and MAC
    addresses.

    network-info has been tested and is known to work on
    Ubuntu, FreeBSD, NetBSD, Mac OS and Windows.

category:             Network
abi:                  94dd8739dbd67e95ebb0d3210e8d13c2
exposed:              True
exposed-modules:      Network.Info
import-dirs:          /usr/lib/ghc-9.0.2/site-local/network-info-0.2.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/network-info-0.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/network-info-0.2.1
hs-libraries:         HSnetwork-info-0.2.1-9GScy3IMZku1XH8B3cDTYU
depends:              base-4.15.1.0
haddock-interfaces:
    /usr/share/doc/haskell-network-info/html/network-info.haddock

haddock-html:         /usr/share/doc/haskell-network-info/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
